function [G1,impact,irf,eu,kappa] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h)
% "A Theory of Intrinsic Inflation Persistence" 
% by Takushi Kurozumi and Willem Van Zandweghe
rho_i = shocks(1,1);
stdmat = [-shocks(1,2) 0; 0 shocks(2,2)];

%% STEADY-STATE CONDITIONS
gamp=thetap*(1+epsp);
s = (1-alpp)/(1-alpp*bigpi^gamp)*((1-alpp*bigpi^(gamp-1))/(1-alpp))^(gamp/(gamp-1));
eps1 = epsp*((1-alpp)/(1-alpp*bigpi^(gamp-1)))^(gamp/(gamp-1));
eps2 = eps1*(1-alpp*beta*bigpi^(gamp-1))/(1-alpp*beta*bigpi^(-1));
kappa = (1-alpp*bigpi^(gamp-1))*(1-alpp*beta*bigpi^gamp) /...
    ( alpp*bigpi^(gamp-1)*(1-eps2*gamp/(gamp-1-eps2)) );
kappadtilde = (1-alpp*bigpi^(gamp-1))*(1-alpp*beta*bigpi^(gamp-1)) /...
    ( alpp*bigpi^(gamp-1)*(1-eps2*(1+gamp)/(gamp-1)) );
kappad = gamp*(kappa-kappadtilde) - alpp*beta*bigpi^gamp - 1/(alpp*bigpi^(gamp-1));
kappaed = -eps1*alpp*bigpi^(-1)*(bigpi^gamp-1) / ((1+eps1)*(1-alpp*bigpi^(-1)));
rhod = alpp*bigpi^(-1)*(1+eps1*bigpi^gamp)/(1+eps1);
kappaf = beta*(bigpi-1)*(1-alpp*bigpi^(gamp-1)) / (1-eps2*(1+gamp)/(gamp-1));
kappaef = eps2*beta*(bigpi^(1+gamp)-1)*(1-alpp*bigpi^(gamp-1)) /...
    ( bigpi^gamp*(gamp-1-eps2*(1+gamp)) );
% mc = ((gamp-1-eps2)/gamp)*(1-alpp*beta*bigpi^gamp)/(1-alpp*beta*bigpi^(gamp-1)) /...
% ( 1/(1+epsp)*((1-alpp)/(1-alpp*bigpi^(gamp-1)))^(1/(1-gamp))+epsp/(1+epsp)*(1-alpp)/(1-alpp*bigpi^(-1)) );
% psiY = 1/mc - (s+epsp)/(1+epsp);
psiY = 0;
gamw=thetaw*(1+epsw);
% sw = (1-alpw)/(1-alpw*bigpi^gamw)*( (1-alpw)/(1-alpw*bigpi^(gamw-1)) )^(gamw/(1-gamw));
eps1w = epsw*( (1-alpw)/(1-alpw*bigpi^(gamw-1)) )^(gamw/(gamw-1));
eps2w = eps1w*(1-alpw*beta*bigpi^(gamw-1)) / (1-alpw*beta*bigpi^(-1));
eps3w = eps1w*(1-alpw*beta*bigpi^(2*gamw))/(1-alpw*beta*bigpi^gamw);
kappaw = (1+eps1w)*(1-alpw*bigpi^(gamw-1))*(1-alpw*beta*bigpi^(2*gamw)) /...
    ( alpw*bigpi^(gamw-1)*((1+eps3w)*(1-eps2w*gamw/(gamw-1-eps2w))+gamw) );
kappadwtilde = (1+eps3w)*(1-alpw*bigpi^(gamw-1))*(1-alpw*beta*bigpi^(gamw-1)) /...
    ( alpw*bigpi^(gamw-1)*((1+eps3w)*(1-eps2w*(1+gamw)/(gamw-1))+gamw*(1-eps2w/(gamw-1))) );
kappadw = gamw*( kappaw*(1+1/(1+eps1w))-kappadwtilde ) - alpw*beta*bigpi^(2*gamw) - 1/(alpw*bigpi^(gamw-1));
kappaew = eps2w*(1+eps3w)*(1-alpw*bigpi^(gamw-1))*(1-alpw*beta*bigpi^(-1)) /...
    ( alpw*bigpi^(gamw-1)*((1+eps3w)*(gamw-1-eps2w*(1+gamw))+gamw*(gamw-1-eps2w)) );
kappaefEHL = -eps3w*beta*bigpi*(bigpi^gamw-1)*(1-alpw*bigpi^(gamw-1)) /...
    ( (1+eps3w)*(1-eps2w*gamw/(gamw-1-eps2w))+gamw );
kappafw = beta*(bigpi^(gamw+1)-1)*(1+eps3w)*(1-alpw*bigpi^(gamw-1)) /...
    ( (1+eps3w)*(1-eps2w*(1+gamw)/(gamw-1))+gamw*(1-eps2w/(gamw-1)) );
kappaefw = -eps2w*beta*(bigpi^(2*gamw+1)-1)*(1+eps3w)*(1-alpw*bigpi^(gamw-1))/...
    ( bigpi^gamw*((1+eps3w)*(gamw-1-eps2w*(1+gamw))+gamw*(gamw-1-eps2w)) );
rhodw = alpw*bigpi^(-1)*(1+eps1w*bigpi^gamw)/(1+eps1w);
kappaedw = -eps1w*alpw*bigpi^(-1)*(bigpi^gamw-1)/( (1+eps1w)*(1-alpw*bigpi^(-1)) );
%% MODEL WITH CURVATURE IN PRODUCT AND LABOR DEMAND CURVES
if alpw>0
    % Variables
    ipi = 1;
    ipiw = 2;
    ii = 3;
    iDelta = 4;
    id = 5;
    idw = 6;
    iN = 7;
    imc = 8;
    iw = 9;
    iY = 10;
    iphi = 11;
    ipsi = 12;
    iphiw = 13;
    ipsiw = 14;
    izetaw = 15;
    ie1pi = 16;
    ie1piw = 17;
    ie1Y = 18;
    ie1N = 19;
    ie1d = 20;
    ie1w = 21;
    ie1dw = 22;
    ie1phi = 23;
    ie1psi = 24;
    ie1phiw = 25;
    ie1psiw = 26;
    ie1zetaw = 27;
    izi = 28;
    %% INITIALIZE MATRICES
    nx = 28;
    nd = 12; %number of expectational variables
    numshock = 1; %number of shocks
    Gamma0 = zeros(nx,nx);
    Gamma1 = zeros(nx,nx);
    %% MODEL EQUATIONS
    %EQUATION 1: EULER EQUATION
    Gamma0(1,iY) = 1;
    Gamma0(1,ie1Y) = -1;
    Gamma0(1,ii) = 1;
    Gamma0(1,ie1pi) = -1;
    %EQUATION 2: TAYLOR RULE
    Gamma0(2,ii) = 1;
    Gamma0(2,ipi) = -(1-rho1)*phip;
    Gamma0(2,iY) = -(1-rho1)*(phiy+phidy);
    Gamma0(2,izi) = -1;
    Gamma1(2,ii) = rho1;
    Gamma1(2,iY) = -(1-rho1)*phidy;
    %EQUATION 3: PRODUCTION FUNCTION
    Gamma0(3,iY) = 1;
    Gamma0(3,iDelta) = 1;
    Gamma0(3,iN) = -(1+psiY*(1+epsp)/(s+epsp));
    %EQUATION 4: LAW OF MOTION FOR RELATIVE PRICE DISTORTION
    Gamma0(4,iDelta) = 1;
    Gamma0(4,ipi) = -(s/(s+epsp))*gamp*alpp*bigpi^(gamp-1)*(bigpi-1)/(1-alpp*bigpi^(gamp-1));
    Gamma0(4,id) = -(s/(s+epsp))*gamp*alpp*bigpi^(gamp-1)*(bigpi-1)/(1-alpp*bigpi^(gamp-1));
    Gamma1(4,id) = -(s/(s+epsp))*gamp*alpp*bigpi^(gamp-1)*(bigpi-1)/(1-alpp*bigpi^(gamp-1));
    Gamma1(4,iDelta) = alpp*bigpi^gamp;
    %EQUATION 5: REAL MARGINAL COST
    Gamma0(5,imc) = 1;
    Gamma0(5,iw) = -1;
    %EQUATION 6: GNKPC
    Gamma0(6,ipi) = 1;
    Gamma0(6,ie1pi) = -beta*bigpi;
    Gamma0(6,ie1d) = -beta*bigpi;
    Gamma0(6,imc) = -kappa;
    Gamma0(6,id) = -kappad;
    Gamma0(6,iphi) = -1;
    Gamma0(6,ipsi) = -1;
    Gamma1(6,id) = 1;
    %EQUATION 7: AUXILIARY PRICE VARIABLE 1
    Gamma0(7,iphi) = -1;
    Gamma0(7,ie1phi) = alpp*beta*bigpi^(gamp-1);
    Gamma0(7,ie1pi) = kappaf*(gamp-1);
    Gamma0(7,ie1d) = kappaf*gamp*(1-alpp*beta*bigpi^(gamp-1));
    %EQUATION 8: LAW OF MOTION FOR PRICE DISPERSION d
    Gamma0(8,id) = 1;
    Gamma0(8,ipi) = -kappaed;
    Gamma1(8,id) = rhod;
    %EQUATION 9: AUXILIARY PRICE VARIABLE 2
    Gamma0(9,ipsi) = -1;
    Gamma0(9,ie1psi) = alpp*beta*bigpi^(-1);
    Gamma0(9,ie1pi) = kappaef;
    %EQUATION 10: WAGE INFLATION
    Gamma0(10,ipiw) = 1;
    Gamma0(10,ipi) = -1;
    Gamma0(10,iw) = -1;
    Gamma1(10,iw) = -1;
    %EQUATION 11: WAGE GNKPC
    Gamma0(11,ipiw) = 1;
    Gamma0(11,ie1piw) = -beta*bigpi^(gamw+1);
    Gamma0(11,iN) = -kappaw*2 + kappadwtilde - kappaew;
    Gamma0(11,iw) = kappaw;
    Gamma0(11,iY) = -(kappadwtilde - kappaew);
    Gamma0(11,idw) = -kappadw;
    Gamma0(11,ie1dw) = -beta*bigpi^(gamw+1);
    Gamma0(11,izetaw) = -1;
    Gamma0(11,iphiw) = -1;
    Gamma0(11,ipsiw) = -1;
    Gamma1(11,idw) = 1;
    %EQUATION 12: AUXILIARY WAGE VARIABLE 1 (phiw)
    Gamma0(12,iphiw) = -1;
    Gamma0(12,ie1phiw) = alpw*beta*bigpi^(gamw-1);
    Gamma0(12,ie1N) = kappafw*(1-alpw*beta*bigpi^(gamw-1));
    Gamma0(12,ie1Y) = -kappafw*(1-alpw*beta*bigpi^(gamw-1));
    Gamma0(12,ie1dw) = kappafw*(1-alpw*beta*bigpi^(gamw-1))*gamw;
    Gamma0(12,ie1piw) = kappafw*gamw;
    Gamma0(12,ie1pi) = -kappafw;
    %EQUATION 13: LAW OF MOTION FOR WAGE DISPERSION dw
    Gamma0(13,idw) = 1;
    Gamma0(13,ipiw) = -kappaedw;
    Gamma1(13,idw) = rhodw;
    %EQUATION 14: AUXILIARY WAGE VARIABLE 2 (psiw)
    Gamma0(14,ipsiw) = -1;
    Gamma0(14,ie1psiw) = alpw*beta*bigpi^(-1);
    Gamma0(14,ie1N) = kappaefw*(1-alpw*beta*bigpi^(-1));
    Gamma0(14,ie1Y) = -kappaefw*(1-alpw*beta*bigpi^(-1));
    Gamma0(14,ie1pi) = -kappaefw;
    %EQUATION 15: AUXILIARY WAGE VARIABLE 3 (zetaw)
    Gamma0(15,izetaw) = -1;
    Gamma0(15,ie1zetaw) = alpw*beta*bigpi^gamw;
    Gamma0(15,ie1N) = kappaefEHL*(1-alpw*beta*bigpi^gamw)*2;
    Gamma0(15,ie1w) = -kappaefEHL*(1-alpw*beta*bigpi^gamw) + kappaefEHL + kappaefEHL*gamw;
    Gamma0(15,ie1dw) = kappaefEHL*(1-alpw*beta*bigpi^gamw)*gamw;
    Gamma0(15,iw) = -kappaefEHL - kappaefEHL*gamw;
    Gamma0(15,ie1pi) = kappaefEHL*gamw;
    %EQUATION 16: Definition of E(t)pi(t+1)
    Gamma0(16,ipi) = 1;
    Gamma1(16,ie1pi) = 1;
    %EQUATION 17: Definition of E(t)piw(t+1)
    Gamma0(17,ipiw) = 1;
    Gamma1(17,ie1piw) = 1;
    %EQUATION 18: Definition of E(t)Y(t+1)
    Gamma0(18,iY) = 1;
    Gamma1(18,ie1Y) = 1;
    %EQUATION 19: Definition of E(t)d(t+1)
    Gamma0(19,id) = 1;
    Gamma1(19,ie1d) = 1;
    %EQUATION 20: Definition of E(t)N(t+1)
    Gamma0(20,iN) = 1;
    Gamma1(20,ie1N) = 1;
    %EQUATION 21: Definition of E(t)w(t+1)
    Gamma0(21,iw) = 1;
    Gamma1(21,ie1w) = 1;
    %EQUATION 22: Definition of E(t)dw(t+1)
    Gamma0(22,idw) = 1;
    Gamma1(22,ie1dw) = 1;
    %EQUATION 23: Definition of E(t)phi(t+1)
    Gamma0(23,iphi) = 1;
    Gamma1(23,ie1phi) = 1;
    %EQUATION 24: Definition of E(t)psi(t+1)
    Gamma0(24,ipsi) = 1;
    Gamma1(24,ie1psi) = 1;
    %EQUATION 25: Definition of E(t)phiw(t+1)
    Gamma0(25,iphiw) = 1;
    Gamma1(25,ie1phiw) = 1;
    %EQUATION 26: Definition of E(t)psiw(t+1)
    Gamma0(26,ipsiw) = 1;
    Gamma1(26,ie1psiw) = 1;
    %EQUATION 27: Definition of E(t)zetaw(t+1)
    Gamma0(27,izetaw) = 1;
    Gamma1(27,ie1zetaw) = 1;
    %EQUATION 28: Monetary policy shock
    Gamma0(28,izi) = 1;
    Gamma1(28,izi) = rho_i;
    
    % CANONICAL FORM FOR GENSYS
    Cst = zeros(nx,1);
    Psi = [zeros(nx-numshock,numshock); stdmat(1,1)];
    Pi = zeros(nx,nd);
    j = 1;
    for i=(nx-numshock-nd+1):(nx-numshock)
        Pi(i,j) = 1;
        j = j+1;
    end
    [G1,~,impact,~,~,~,~,eu,~] = gensys(Gamma0,Gamma1,Cst,Psi,Pi,1+1E-8);
    %% Plot impulse responses
    irf = zeros(nx,h+1);
    if h>0
        for i = 1:h+1
            irf(:,i) = (G1^(i-1))*impact(:,1);
        end
    end 
%% Case of flexible wages
elseif alpw==0
    eps1w = epsw;
    eps2w = eps1w;
    eps3w = eps1w;
%     Multiply coefficients of labor supply condition by alpw
    kappaw = (1+eps1w) /...
        ( bigpi^(gamw-1)*((1+eps3w)*(1-eps2w*gamw/(gamw-1-eps2w))+gamw) );
    kappadwtilde = (1+eps3w) /...
        ( bigpi^(gamw-1)*((1+eps3w)*(1-eps2w*(1+gamw)/(gamw-1))+gamw*(1-eps2w/(gamw-1))) );
%     kappadw = gamw*( kappaw*(1+1/(1+eps1w))-kappadwtilde ) - alpw*beta*bigpi^(2*gamw) - 1/(alpw*bigpi^(gamw-1));
    kappaew = eps2w*(1+eps3w) /...
        ( bigpi^(gamw-1)*((1+eps3w)*(gamw-1-eps2w*(1+gamw))+gamw*(gamw-1-eps2w)) );
%     kappaefEHL = -eps3w*beta*bigpi*(bigpi^gamw-1)*(1-alpw*bigpi^(gamw-1)) /...
%         ( (1+eps3w)*(1-eps2w*gamw/(gamw-1-eps2w))+gamw );
%     kappafw = beta*(bigpi^(gamw+1)-1)*(1+eps3w)*(1-alpw*bigpi^(gamw-1)) /...
%         ( (1+eps3w)*(1-eps2w*(1+gamw)/(gamw-1))+gamw*(1-eps2w/(gamw-1)) );
%     kappaefw = -eps2w*beta*(bigpi^(2*gamw+1)-1)*(1+eps3w)*(1-alpw*bigpi^(gamw-1))/...
%         ( bigpi^gamw*((1+eps3w)*(gamw-1-eps2w*(1+gamw))+gamw*(gamw-1-eps2w)) );
%     rhodw = alpw*bigpi^(-1)*(1+eps1w*bigpi^gamw)/(1+eps1w);
%     kappaedw = -eps1w*alpw*bigpi^(-1)*(bigpi^gamw-1)/( (1+eps1w)*(1-alpw*bigpi^(-1)) );    
    % Variables
    ipi = 1;
%     ipiw = 2;
    ii = 2;
    iDelta = 3;
    id = 4;
%     idw = 6;
    iN = 5;
    imc = 6;
    iw = 7;
    iY = 8;
    iphi = 9;
    ipsi = 10;
%     iphiw = 13;
%     ipsiw = 14;
%     izetaw = 15;
    ie1pi = 11;
%     ie1piw = 17;
    ie1Y = 12;
%     ie1N = 13;
    ie1d = 13;
%     ie1w = 21;
%     ie1dw = 22;
    ie1phi = 14;
    ie1psi = 15;
%     ie1phiw = 25;
%     ie1psiw = 26;
%     ie1zetaw = 27;
    izi = 16;
    %% INITIALIZE MATRICES
    nx = 16;
    nd = 5; %number of expectational variables
    numshock = 1; %number of shocks
    Gamma0 = zeros(nx,nx);
    Gamma1 = zeros(nx,nx);
    %% MODEL EQUATIONS
    %EQUATION 1: EULER EQUATION
    Gamma0(1,iY) = 1;
    Gamma0(1,ie1Y) = -1;
    Gamma0(1,ii) = 1;
    Gamma0(1,ie1pi) = -1;
    %EQUATION 2: TAYLOR RULE
    Gamma0(2,ii) = 1;
    Gamma0(2,ipi) = -(1-rho1)*phip;
    Gamma0(2,iY) = -(1-rho1)*(phiy+phidy);
    Gamma0(2,izi) = -1;
    Gamma1(2,ii) = rho1;
    Gamma1(2,iY) = -(1-rho1)*phidy;
    %EQUATION 3: PRODUCTION FUNCTION
    Gamma0(3,iY) = 1;
    Gamma0(3,iDelta) = 1;
    Gamma0(3,iN) = -(1+psiY*(1+epsp)/(s+epsp));
    %EQUATION 4: LAW OF MOTION FOR RELATIVE PRICE DISTORTION
    Gamma0(4,iDelta) = 1;
    Gamma0(4,ipi) = -(s/(s+epsp))*gamp*alpp*bigpi^(gamp-1)*(bigpi-1)/(1-alpp*bigpi^(gamp-1));
    Gamma0(4,id) = -(s/(s+epsp))*gamp*alpp*bigpi^(gamp-1)*(bigpi-1)/(1-alpp*bigpi^(gamp-1));
    Gamma1(4,id) = -(s/(s+epsp))*gamp*alpp*bigpi^(gamp-1)*(bigpi-1)/(1-alpp*bigpi^(gamp-1));
    Gamma1(4,iDelta) = alpp*bigpi^gamp;
    %EQUATION 5: REAL MARGINAL COST
    Gamma0(5,imc) = 1;
    Gamma0(5,iw) = -1;
    %EQUATION 6: GNKPC
    Gamma0(6,ipi) = 1;
    Gamma0(6,ie1pi) = -beta*bigpi;
    Gamma0(6,ie1d) = -beta*bigpi;
    Gamma0(6,imc) = -kappa;
    Gamma0(6,id) = -kappad;
    Gamma0(6,iphi) = -1;
    Gamma0(6,ipsi) = -1;
    Gamma1(6,id) = 1;
    %EQUATION 7: AUXILIARY PRICE VARIABLE 1
    Gamma0(7,iphi) = -1;
    Gamma0(7,ie1phi) = alpp*beta*bigpi^(gamp-1);
    Gamma0(7,ie1pi) = kappaf*(gamp-1);
    Gamma0(7,ie1d) = kappaf*gamp*(1-alpp*beta*bigpi^(gamp-1));
    %EQUATION 8: LAW OF MOTION FOR PRICE DISPERSION d
    Gamma0(8,id) = 1;
    Gamma0(8,ipi) = -kappaed;
    Gamma1(8,id) = rhod;
    %EQUATION 9: AUXILIARY PRICE VARIABLE 2
    Gamma0(9,ipsi) = -1;
    Gamma0(9,ie1psi) = alpp*beta*bigpi^(-1);
    Gamma0(9,ie1pi) = kappaef;
    %EQUATION 10: WAGE INFLATION
%     Gamma0(10,ipiw) = 1;
%     Gamma0(10,ipi) = -1;
%     Gamma0(10,iw) = -1;
%     Gamma1(10,iw) = -1;
    %EQUATION 11: WAGE GNKPC
%     Gamma0(11,ipiw) = 1;
%     Gamma0(11,ie1piw) = -beta*bigpi^(gamw+1);
    Gamma0(10,iN) = -kappaw*2 + kappadwtilde - kappaew;
    Gamma0(10,iw) = kappaw;
    Gamma0(10,iY) = -(kappadwtilde - kappaew);
%     Gamma0(11,idw) = -kappadw;
%     Gamma0(11,ie1dw) = -beta*bigpi^(gamw+1);
%     Gamma0(11,izetaw) = -1;
%     Gamma0(11,iphiw) = -1;
%     Gamma0(11,ipsiw) = -1;
%     Gamma1(11,idw) = 1;
    %EQUATION 12: AUXILIARY WAGE VARIABLE 1 (phiw)
%     Gamma0(12,iphiw) = -1;
%     Gamma0(12,ie1phiw) = alpw*beta*bigpi^(gamw-1);
%     Gamma0(12,ie1N) = kappafw*(1-alpw*beta*bigpi^(gamw-1));
%     Gamma0(12,ie1Y) = -kappafw*(1-alpw*beta*bigpi^(gamw-1));
%     Gamma0(12,ie1dw) = kappafw*(1-alpw*beta*bigpi^(gamw-1))*gamw;
%     Gamma0(12,ie1piw) = kappafw*gamw;
%     Gamma0(12,ie1pi) = -kappafw;
    %EQUATION 13: LAW OF MOTION FOR WAGE DISPERSION dw
%     Gamma0(13,idw) = 1;
%     Gamma0(13,ipiw) = -kappaedw;
%     Gamma1(13,idw) = rhodw;
    %EQUATION 14: AUXILIARY WAGE VARIABLE 2 (psiw)
%     Gamma0(14,ipsiw) = -1;
%     Gamma0(14,ie1psiw) = alpw*beta*bigpi^(-1);
%     Gamma0(14,ie1N) = kappaefw*(1-alpw*beta*bigpi^(-1));
%     Gamma0(14,ie1Y) = -kappaefw*(1-alpw*beta*bigpi^(-1));
%     Gamma0(14,ie1pi) = -kappaefw;
    %EQUATION 15: AUXILIARY WAGE VARIABLE 3 (zetaw)
%     Gamma0(15,izetaw) = -1;
%     Gamma0(15,ie1zetaw) = alpw*beta*bigpi^gamw;
%     Gamma0(15,ie1N) = kappaefEHL*(1-alpw*beta*bigpi^gamw)*2;
%     Gamma0(15,ie1w) = -kappaefEHL*(1-alpw*beta*bigpi^gamw) + kappaefEHL + kappaefEHL*gamw;
%     Gamma0(15,ie1dw) = kappaefEHL*(1-alpw*beta*bigpi^gamw)*gamw;
%     Gamma0(15,iw) = -kappaefEHL - kappaefEHL*gamw;
%     Gamma0(15,ie1pi) = kappaefEHL*gamw;
    %EQUATION 16: Definition of E(t)pi(t+1)
    Gamma0(11,ipi) = 1;
    Gamma1(11,ie1pi) = 1;
    %EQUATION 17: Definition of E(t)piw(t+1)
%     Gamma0(17,ipiw) = 1;
%     Gamma1(17,ie1piw) = 1;
    %EQUATION 18: Definition of E(t)Y(t+1)
    Gamma0(12,iY) = 1;
    Gamma1(12,ie1Y) = 1;
    %EQUATION 19: Definition of E(t)d(t+1)
    Gamma0(13,id) = 1;
    Gamma1(13,ie1d) = 1;
    %EQUATION 20: Definition of E(t)N(t+1)
%     Gamma0(14,iN) = 1;
%     Gamma1(14,ie1N) = 1;
    %EQUATION 21: Definition of E(t)w(t+1)
%     Gamma0(21,iw) = 1;
%     Gamma1(21,ie1w) = 1;
    %EQUATION 22: Definition of E(t)dw(t+1)
%     Gamma0(22,idw) = 1;
%     Gamma1(22,ie1dw) = 1;
    %EQUATION 23: Definition of E(t)phi(t+1)
    Gamma0(14,iphi) = 1;
    Gamma1(14,ie1phi) = 1;
    %EQUATION 24: Definition of E(t)psi(t+1)
    Gamma0(15,ipsi) = 1;
    Gamma1(15,ie1psi) = 1;
    %EQUATION 25: Definition of E(t)phiw(t+1)
%     Gamma0(25,iphiw) = 1;
%     Gamma1(25,ie1phiw) = 1;
    %EQUATION 26: Definition of E(t)psiw(t+1)
%     Gamma0(26,ipsiw) = 1;
%     Gamma1(26,ie1psiw) = 1;
    %EQUATION 27: Definition of E(t)zetaw(t+1)
%     Gamma0(27,izetaw) = 1;
%     Gamma1(27,ie1zetaw) = 1;
    %EQUATION 28: Monetary policy shock
    Gamma0(16,izi) = 1;
    Gamma1(16,izi) = rho_i;
    
    % CANONICAL FORM FOR GENSYS
    Cst = zeros(nx,1);
    Psi = [zeros(nx-numshock,numshock); stdmat(1,1)];
    Pi = zeros(nx,nd);
    j = 1;
    for i=(nx-numshock-nd+1):(nx-numshock)
        Pi(i,j) = 1;
        j = j+1;
    end
    [G1,~,impact,~,~,~,~,eu,~] = gensys(Gamma0,Gamma1,Cst,Psi,Pi,1+1E-8);
    %% Plot impulse responses
    irf = zeros(nx,h+1);
    if h>0
        for i = 1:h+1
            irf(:,i) = (G1^(i-1))*impact(:,1);
        end
    end
end