function [G1,irf,eu] = ATIIP_indexation_fun(iotap,iotaw,beta,sigman,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,sigma_i,h)
% "A Theory of Intrinsic Inflation Persistence" 
% by Takushi Kurozumi and Willem Van Zandweghe
%% CALIBRATION
rho = 0; 
kappa = (1-alpp)*(1-alpp*beta)/(alpp*(1-epsp*thetap/(thetap-1)));
if alpw>0
    kappaw = (1-alpw)*(1-alpw*beta)/(alpw*(1+thetaw*sigman-epsw*thetaw/(thetaw-1)));
    %% MODEL 
    nx = 10;
    ipi = 1;
    ipiw = 2;
    ii = 3;
    imc = 4;
    iw = 5;
    iY = 6;
    ie1pi = 7;
    ie1piw = 8;
    ie1Y = 9;
    izi = 10;
    Gamma0 = zeros(nx,nx);
    Gamma1 = zeros(nx,nx);
    %EQUATION 1: EULER EQUATION
    Gamma0(1,iY) = 1;
    Gamma0(1,ie1Y) = -1;
    Gamma0(1,ii) = 1;
    Gamma0(1,ie1pi) = -1;
    %EQUATION 2: TAYLOR RULE
    Gamma0(2,ii) = 1;
    Gamma0(2,ipi) = -(1-rho1)*phip;
    Gamma0(2,iY) = -(1-rho1)*(phiy+phidy);
    Gamma0(2,izi) = -1;
    Gamma1(2,ii) = rho1;
    Gamma1(2,iY) = -(1-rho1)*phidy;
    %EQUATION 3: REAL MARGINAL COST
    Gamma0(3,imc) = 1;
    Gamma0(3,iw) = -1;
    %EQUATION 4: NKPC
    Gamma0(4,ipi) = 1 + beta*iotap;
    Gamma0(4,ie1pi) = -beta;
    Gamma0(4,imc) = -kappa;
    Gamma1(4,ipi) = iotap;
    %EQUATION 5: WAGE INFLATION
    Gamma0(5,ipiw) = 1;
    Gamma0(5,ipi) = -1;
    Gamma0(5,iw) = -1;
    Gamma1(5,iw) = -1;
    %EQUATION 6: WAGE GNKPC
    Gamma0(6,ipiw) = 1+beta*iotaw;
    Gamma0(6,ie1piw) = -beta;
    Gamma0(6,iw) = kappaw;
    Gamma0(6,iY) = -(1+sigman)*kappaw;
    Gamma1(6,ipi) = iotaw;
    %EQUATION 7: Definition of E(t)pi(t+1)
    Gamma0(7,ipi) = 1;
    Gamma1(7,ie1pi) = 1;
    %EQUATION 8: Definition of E(t)piw(t+1)
    Gamma0(8,ipiw) = 1;
    Gamma1(8,ie1piw) = 1;
    %EQUATION 9: Definition of E(t)Y(t+1)
    Gamma0(9,iY) = 1;
    Gamma1(9,ie1Y) = 1;
    %EQUATION 10: Monetary policy shock
    Gamma0(10,izi) = 1;
    Gamma1(10,izi) = rho;
    % SOLUTION USING GENSYS
    Cst = zeros(nx,1);
    Psi = [zeros(nx-1,1); -sigma_i];
    Pi = zeros(nx,3);
    Pi(nx-3,1) = 1;
    Pi(nx-2,2) = 1;
    Pi(nx-1,3) = 1;
    [G1,~,impact,~,~,~,~,eu] = gensys(Gamma0,Gamma1,Cst,Psi,Pi);
    %% Plot impulse responses
    irf = zeros(nx,h+1);
    if h>0
        for i = 1:h+1
            irf(:,i) = (G1^(i-1))*impact(:,1);
        end
    end
elseif alpw==0
%     Multiply coefficients of labor supply condition by alpw    
    kappaw = (1-alpw)*(1-alpw*beta)/((1+thetaw*sigman-epsw*thetaw/(thetaw-1)));
    %% MODEL 
    nx = 8;
    ipi = 1;
%     ipiw = 2;
    ii = 2;
    imc = 3;
    iw = 4;
    iY = 5;
    ie1pi = 6;
%     ie1piw = 8;
    ie1Y = 7;
    izi = 8;
    Gamma0 = zeros(nx,nx);
    Gamma1 = zeros(nx,nx);
    %EQUATION 1: EULER EQUATION
    Gamma0(1,iY) = 1;
    Gamma0(1,ie1Y) = -1;
    Gamma0(1,ii) = 1;
    Gamma0(1,ie1pi) = -1;
    %EQUATION 2: TAYLOR RULE
    Gamma0(2,ii) = 1;
    Gamma0(2,ipi) = -(1-rho1)*phip;
    Gamma0(2,iY) = -(1-rho1)*(phiy+phidy);
    Gamma0(2,izi) = -1;
    Gamma1(2,ii) = rho1;
    Gamma1(2,iY) = -(1-rho1)*phidy;
    %EQUATION 3: REAL MARGINAL COST
    Gamma0(3,imc) = 1;
    Gamma0(3,iw) = -1;
    %EQUATION 4: NKPC
    Gamma0(4,ipi) = 1 + beta*iotap;
    Gamma0(4,ie1pi) = -beta;
    Gamma0(4,imc) = -kappa;
    Gamma1(4,ipi) = iotap;
    %EQUATION 5: WAGE INFLATION
%     Gamma0(5,ipiw) = 1;
%     Gamma0(5,ipi) = -1;
%     Gamma0(5,iw) = -1;
%     Gamma1(5,iw) = -1;
    %EQUATION 6: WAGE GNKPC
%     Gamma0(6,ipiw) = 1+beta*iotaw;
%     Gamma0(6,ie1piw) = -beta;
    Gamma0(5,iw) = kappaw;
    Gamma0(5,iY) = -(1+sigman)*kappaw;
%     Gamma1(6,ipi) = iotaw;
    %EQUATION 7: Definition of E(t)pi(t+1)
    Gamma0(6,ipi) = 1;
    Gamma1(6,ie1pi) = 1;
    %EQUATION 8: Definition of E(t)piw(t+1)
%     Gamma0(8,ipiw) = 1;
%     Gamma1(8,ie1piw) = 1;
    %EQUATION 9: Definition of E(t)Y(t+1)
    Gamma0(7,iY) = 1;
    Gamma1(7,ie1Y) = 1;
    %EQUATION 10: Monetary policy shock
    Gamma0(8,izi) = 1;
    Gamma1(8,izi) = rho;
    % SOLUTION USING GENSYS
    Cst = zeros(nx,1);
    Psi = [zeros(nx-1,1); -sigma_i];
    Pi = zeros(nx,3);
    Pi(nx-2,1) = 1;
    Pi(nx-1,2) = 1;
    [G1,~,impact,~,~,~,~,eu] = gensys(Gamma0,Gamma1,Cst,Psi,Pi);
    %% Plot impulse responses
    irf = zeros(nx,h+1);
    if h>0
        for i = 1:h+1
            irf(:,i) = (G1^(i-1))*impact(:,1);
        end
    end
end
