% "A Theory of Intrinsic Inflation Persistence" 
% by Takushi Kurozumi and Willem Van Zandweghe
% Figure 2
clear; clc
h = 32;
%% Calibration
bigpi = 1.032^0.25; % Sample average for GDP deflator of sample 1959Q1-2019Q4
beta = 0.99;
sigman = 1;
epsp = -3;
epsw = -3;
thetap = 10;
thetaw = 10;
alpp = 0.75;
alpw = 0.75;
phip = 1.5;
phiy = 0.125;
phidy = 0; 
rho1 = 0.8;
rho_i = 0; 
std_i = 0.0025; 
rho_a = 0;
std_a = 0;
shocks = [rho_i std_i; rho_a std_a];

%% Compute IRFs
disp('Baseline')
    [~,~,irf_base,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
disp('Indexation to trend inflation')
    iotap = 0;
    iotaw = 0;
    [~,irf_trend,eu] = ATIIP_indexation_fun(iotap,iotaw,beta,sigman,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,std_i,h);
    if sum(eu)<2; disp('No unique solution'); end
disp('Indexation to past inflation')
    iotap = 0.24;
    iotaw = 0.58;
    [~,irf_past,eu] = ATIIP_indexation_fun(iotap,iotaw,beta,sigman,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,std_i,h);
    if sum(eu)<2; disp('No unique solution'); end
%% Plot responses to a one-standard-deviation accommodative shock
h = 32;
xlim = [1 h+1];
xtick = (1:4:h+1);
figure
subplot(3,2,1)
    ha = plot([400*irf_base(3,:); 400*irf_trend(3,:); 400*irf_past(3,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(ha(3),'LineWidth',1.2,'LineStyle',':','Color',[0 0 0]);
    set(gca,'YLim',[-1 0.01 ],'YTick',[-0.9 -0.6 -0.3 0])
   	ylabel('pp   ','Rotation',0)
    h = legend([ ha(1) ha(2) ha(3) ],'No indexation',...
        'Index. to trend inflation',...
        'Index. to past inflation','Location','southeast');
    set(h,'Interpreter','latex')
    title('Interest rate')
subplot(3,2,2)
    ha = plot([400*irf_base(1,:); 400*irf_trend(1,:); 400*irf_past(1,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(ha(3),'LineWidth',1.2,'LineStyle',':','Color',[0 0 0]);
    set(gca,'YLim',[-0.001 0.06],'YTick',[0 0.02 0.04 0.06])
    ylabel('pp   ','Rotation',0)
    title('Inflation')
subplot(3,2,3)
    ha = plot(100*irf_base(5,:)');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
   	set(gca,'YLim',[-0.0005 0.02],'YTick',[ 0 0.01 0.02 ])
    ax = gca;
    ax.YAxis.Exponent = 0;
   	ylabel('%  ','Rotation',0)
    title('RMC of goods aggregation')
subplot(3,2,4)
    ha = plot(100*irf_base(6,:)');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
   	set(gca,'YLim',[-0.004 0.04],'YTick',[ 0 0.02 0.04 ])
    ax = gca;
    ax.YAxis.Exponent = 0;
   	ylabel('%  ','Rotation',0)
    title('RMC of labor aggregation')
subplot(3,2,5)
    ha = plot([100*irf_base(8,:); 100*irf_trend(4,:); 100*irf_past(4,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(ha(3),'LineWidth',1.2,'LineStyle',':','Color',[0 0 0]);
    xlabel('Quarters since shock')
   	ylabel('%  ','Rotation',0)
    set(gca,'YLim',[-0.001 0.06],'YTick',[0 0.02 0.04 0.06])
    title('RMC of goods production')
subplot(3,2,6)
    ha = plot([100*irf_base(10,:); 100*irf_trend(6,:); 100*irf_past(6,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(ha(3),'LineWidth',1.2,'LineStyle',':','Color',[0 0 0]);
    set(gca,'YLim',[-0.05 1],'YTick',[0 0.3 0.6 0.9])
    xlabel('Quarters since shock')
   	ylabel('%  ','Rotation',0)
    title('Output')

set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [5 5]);
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperPosition', [-0.3 -0.1 5.6 5.2 ]);
set(gcf, 'renderer', 'painters');
print(gcf, '-dpdf', 'fig2_irf.pdf');
