% "A Theory of Intrinsic Inflation Persistence" 
% by Takushi Kurozumi and Willem Van Zandweghe
% Figure 3
clear; clc
%% Calibration
h = 32;
bigpi = 1.032^0.25; % Sample average for GDP deflator of sample 1959Q1-2019Q4
beta = 0.99;
thetap = 10;
thetaw = 10;
epsp = -3;
epsw = -3;
alpp = 0.75;
alpw = 0.75;
% sigman = 1;
phip = 1.5;
phiy = 0.125;
phidy = 0;
rho1 = 0.8;
rho_i = 0; 
std_i = 0.0025; 
rho_a = 0;
std_a = 0;
shocks = [rho_i std_i; rho_a std_a];
%% Compute IRFs
disp('baseline')
    % [irf_base,eu] = ATIP_fun(bigpi,0.99,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,sigma_i,h);
    [~,~,irf_base,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
disp('epsp=0')
    epsp = 0;
    [~,~,irf_epspl,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
disp('epsp=-6')
    epsp = -6;
    [~,~,irf_epsph,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
    epsp = -3;
disp('epsw=-0.6')
    epsw = -0.6;
    [~,~,irf_epswl,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
disp('epsw=-6')
    epsw = -6;
    [~,~,irf_epswh,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
    epsw = -3;
disp('alpp=0.5')
    alpp = 0.5;
    [~,~,irf_alppl,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
disp('alpp=0.85')
    alpp = 0.85;
    [~,~,irf_alpph,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
    alpp = 0.75;
disp('alpw=0.5')
    alpw = 0.5;
    [~,~,irf_alpwl,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
disp('alpw=0.85')
    alpw = 0.85;
    [~,~,irf_alpwh,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
    alpw = 0.75;
%% Plot responses to a one-standard-deviation accommodative shock
% figure
xlim = [1 h+1];
xtick = (1:4:h+1);
figure
subplot(2,2,1)
    ha = plot([400*irf_base(1,:); 400*irf_epspl(1,:); 400*irf_epsph(1,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(ha(3),'LineWidth',1.2,'LineStyle',':','Color',[0 0 0]);
    set(gca,'YLim',[-0.001 0.08],'YTick',[0 0.02 0.04 0.06 0.08])
    ylabel('pp   ','Rotation',0)
    hleg = legend([ ha(1) ha(2) ha(3) ],'Baseline','$\epsilon_p = 0$','$\epsilon_p=-6$',...
        'Location','NorthEast');
    set(hleg,'Interpreter','latex')    
    ax = gca;
    ax.YAxis.Exponent = 0;   
subplot(2,2,2)
    ha = plot([400*irf_base(1,:); 400*irf_epswl(1,:); 400*irf_epswh(1,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(ha(3),'LineWidth',1.2,'LineStyle',':','Color',[0 0 0]);
   	ylabel('pp   ','Rotation',0)
    set(gca,'YLim',[-0.001 0.08],'YTick',[0 0.02 0.04 0.06 0.08])
    hleg = legend([ ha(1) ha(2) ha(3) ],'Baseline','$\epsilon_w = -0.6$','$\epsilon_w=-6$',...
        'Location','NorthEast');
    set(hleg,'Interpreter','latex')    
    ax = gca;
    ax.YAxis.Exponent = 0;   
subplot(2,2,3)
    ha = plot([400*irf_base(1,:); 400*irf_alppl(1,:); 400*irf_alpph(1,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(ha(3),'LineWidth',1.2,'LineStyle',':','Color',[0 0 0]);
    set(gca,'YLim',[-0.002 0.12],'YTick',[0 0.03 0.06 0.09 0.12])
    xlabel('Quarters since shock')
   	ylabel('pp   ','Rotation',0)
    hleg = legend([ ha(1) ha(2) ha(3) ],'Baseline','$\alpha_p = 0.5$','$\alpha_p=0.85$',...
        'Location','NorthEast');
    set(hleg,'Interpreter','latex')    
    ax = gca;
    ax.YAxis.Exponent = 0;   
subplot(2,2,4)
    ha = plot([400*irf_base(1,:); 400*irf_alpwl(1,:); 400*irf_alpwh(1,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(ha(3),'LineWidth',1.2,'LineStyle',':','Color',[0 0 0]);
    xlabel('Quarters since shock')
    ylabel('pp   ','Rotation',0)
    set(gca,'YLim',[-0.002 0.12],'YTick',[0 0.03 0.06 0.09 0.12])
    hleg = legend([ ha(1) ha(2) ha(3) ],'Baseline','$\alpha_w = 0.5$','$\alpha_w=0.85$',...
        'Location','NorthEast');
    set(hleg,'Interpreter','latex')    
    ax = gca;
    ax.YAxis.Exponent = 0;   

set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [5 3.4]);
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperPosition', [-0.3 -0.1 5.6 3.6 ]);
set(gcf, 'renderer', 'painters');
print(gcf, '-dpdf', 'fig3_robustness.pdf');
