% "A Theory of Intrinsic Inflation Persistence" 
% by Takushi Kurozumi and Willem Van Zandweghe
% Figure 4
clear
close all
h = 24;
%% Calibration
bigpi = 1.036^0.25; % Sample average for GDP deflator and PCE inflation of sample 1959Q1-2008Q4
beta = 0.99;
g = 1;
b = 0.7;
sigman = 1;
epsp = -3;
epsw = -3; 
thetap = 10;
thetaw = 10;
alpp = 0.75;
alpw = 0.75;
phip = 1.5;
phiy = 0.125;
phidy = 1; 
rho1 = 0.8;
rho_i = 0; 
rho_a = 0;
std_i = 0.0025;
std_a = 0.01;
shocks = [rho_i std_i; rho_a std_a];

disp('Baseline model')
    [~,~,irf_base_m,eu_base] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    eu = eu_base;
    if sum(eu)<2; disp('No unique solution'); end
disp('Extended model')
    [~,~,irf_ext,eu_ext,kappa] = ATIIP_extmod_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,b,g,shocks,h);
    irf_ext_m = irf_ext(1:size(irf_ext,1)/2,:);
    irf_ext_a = irf_ext(size(irf_ext,1)/2+1:end,:);
    eu = eu_ext;
    if sum(eu)<2; disp('No unique solution'); end
save DSGE_IRFs irf_ext_a irf_ext_m
%% Plot responses to a one-standard-deviation accommodative shock
load('DSGE_IRFs.mat')
load('VAR_IRFsAndSEs.mat') %Source: Christiano, Eichenbaum and Trabandt (AEJM 2015)
% Empirical impulse responses to a technology shock
i_ctw_a = IRFz(:,3)/100;
pi_ctw_a = IRFz(:,2)/100;
i_ctw_ase = IRFzSE(:,3)/100;
pi_ctw_ase = IRFzSE(:,2)/100;
% Empirical impulse responses to a monetary policy shock
i_ctw_m = -IRFFF(:,3)/100;
pi_ctw_m = -IRFFF(:,2)/100;
i_ctw_mse = IRFFFSE(:,3)/100;
pi_ctw_mse = IRFFFSE(:,2)/100;
tt = (0:19)';
i_mod_a = 400*irf_ext_a(3,1:20)';
pi_mod_a = 400*irf_ext_a(1,1:20)';
i_mod_m = 400*irf_ext_m(3,1:20)';
pi_mod_m = 400*irf_ext_m(1,1:20)';
figure('name','VAR and model impulse responses','NumberTitle','off')
grayColor = [.7 .7 .7];
tt = tt';
% Set transparency of filled area
a = .4;
% Set linestyle of filled area
l = 'none';
x2 = [tt, fliplr(tt)];
subplot(2,2,1)
    plot(tt,i_ctw_m','k--',tt,i_mod_m','b-','LineWidth',1.2)
    set(gca,'FontSize',7)
    hold on
    set(gca,'XLim',[0 20],'XTick',(0:4:20),'XTickLabel',{'0','4','8','12','16','20'})
    set(gca,'YLim',[-0.82 0.22],'YTick',[-0.6 -0.4 -0.2 0 0.2])
    inBetween = [(i_ctw_m-1.96*i_ctw_mse)', fliplr((i_ctw_m+1.96*i_ctw_mse)')];
    fill(x2, inBetween, grayColor,'FaceAlpha',a,'LineStyle',l);
    title('Interest rate to a policy shock')
    ylabel('pp   ','Rotation',0)
subplot(2,2,2)
    plot(tt,pi_ctw_m','k--',tt,pi_mod_m','b-','LineWidth',1.2)
    set(gca,'FontSize',7)
    hold on
    set(gca,'XLim',[0 20],'XTick',(0:4:20),'XTickLabel',{'0','4','8','12','16','20'})
    set(gca,'YLim',[-0.17 0.25],'YTick',[-0.1 0 0.1 0.2])
    inBetween = [(pi_ctw_m-1.96*pi_ctw_mse)', fliplr((pi_ctw_m+1.96*pi_ctw_mse)')];
    fill(x2, inBetween, grayColor,'FaceAlpha',a,'LineStyle',l);
    title('Inflation to a policy shock')
    ylabel('pp   ','Rotation',0)
subplot(2,2,3)
    plot(tt,i_ctw_a','k--',tt,i_mod_a','b-','LineWidth',1.2)
    set(gca,'FontSize',7)
    hold on
    set(gca,'XLim',[0 20],'XTick',(0:4:20),'XTickLabel',{'0','4','8','12','16','20'})
    set(gca,'YLim',[-0.42 0.22],'YTick',[-0.4 -0.2 0 0.2])
    inBetween = [(i_ctw_a-1.96*i_ctw_ase)', fliplr((i_ctw_a+1.96*i_ctw_ase)')];
    fill(x2, inBetween, grayColor,'FaceAlpha',a,'LineStyle',l);
    title('Interest rate to a technology shock')
    xlabel('Quarters since shock')
    ylabel('pp   ','Rotation',0)
subplot(2,2,4)
    plot(tt,pi_ctw_a','k--',tt,pi_mod_a','b-','LineWidth',1.2)
    set(gca,'FontSize',7)
    hold on
    set(gca,'XLim',[0 20],'XTick',(0:4:20),'XTickLabel',{'0','4','8','12','16','20'})
    set(gca,'YLim',[-0.8 0.02],'YTick',[-0.8 -0.6 -0.4 -0.2 0])    
    inBetween = [(pi_ctw_a-1.96*pi_ctw_ase)', fliplr((pi_ctw_a+1.96*pi_ctw_ase)')];
    fill(x2, inBetween, grayColor,'FaceAlpha',a,'LineStyle',l);
    title('Inflation to a technology shock')
    xlabel('Quarters since shock')
    ylabel('pp   ','Rotation',0)
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [5 3.4]);
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperPosition', [-0.3 -0.1 5.6 3.6 ]);
set(gcf, 'renderer', 'painters');
print(gcf, '-dpdf', 'fig4_irf_dsge_var.pdf');
