% "A Theory of Intrinsic Inflation Persistence" 
% by Takushi Kurozumi and Willem Van Zandweghe
% Figure 5
clear; clc
%% Calibration
beta = 0.99;
epsp = -3;
epsw = -3;
thetap = 10;
thetaw = 10;
alpp = 0.75;
alpw = 0.75;
bigpibar = round((0:0.1:10),1);
bigpi = (1+bigpibar/100).^0.25;
lambdap = lpfn(bigpi,beta,epsp,thetap,alpp);
lambdaw = lwfn(bigpi,beta,epsw,thetaw,alpw);
a = [2.0,3.2,4.1,6.7]';
b = ismember(bigpibar,a);
pivals = find(b);
disp('Degree of intrinsic inertia of inflation')
disp(lambdap(pivals))
disp('Degree of intrinsic inertia of wage inflation')
disp(lambdaw(pivals))
%% Plot figure
figure
ha = plot(bigpibar,[lambdap;lambdaw]);
% set(gca,'FontSize',7)
set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
set(gca,'YLim',[0 0.6],'YTick',[0 0.1 0.2 0.3 0.4 0.5 0.6])
xlabel('Trend inflation (%)')
hleg = legend([ ha(1) ha(2) ],'$\lambda_{p\epsilon}$','$\lambda_{w\epsilon}$','Location','NorthWest');
set(hleg,'Interpreter','latex')
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [5 3.4]);
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperPosition', [-0.3 0 5.6 3.4 ]);
set(gcf, 'renderer', 'painters');
print(gcf, '-dpdf', 'fig5_inertia.pdf');
%% Functions
function lambdap = lpfn(bigpi,beta,epsp,thetap,alpp)
    gamp=thetap*(1+epsp);
    eps1 = epsp*((1-alpp)./(1-alpp*bigpi.^(gamp-1))).^(gamp/(gamp-1));
    eps2 = eps1.*(1-alpp*beta*bigpi.^(gamp-1))./(1-alpp*beta*bigpi.^(-1));
    kappa = (1-alpp*bigpi.^(gamp-1)).*(1-alpp*beta*bigpi.^gamp) ./...
        ( alpp*bigpi.^(gamp-1)*(1-eps2*gamp/(gamp-1-eps2)) );
    kappadtilde = (1-alpp*bigpi.^(gamp-1)).*(1-alpp*beta*bigpi.^(gamp-1)) ./...
        ( alpp*bigpi.^(gamp-1).*(1-eps2*(1+gamp)/(gamp-1)) );
    kappad = gamp*(kappa-kappadtilde) - alpp*beta*bigpi.^gamp - 1./(alpp*bigpi.^(gamp-1));
    kappaed = -eps1*alpp.*bigpi.^(-1).*(bigpi.^gamp-1) ./ ((1+eps1).*(1-alpp*bigpi.^(-1)));
    rhod = alpp*bigpi.^(-1).*(1+eps1.*bigpi.^gamp)./(1+eps1);
    bp3 = 1-kappaed.*(kappad+beta*bigpi.*rhod);
    bp1 = kappaed.*(1+rhod.*(kappad+beta*bigpi.*rhod))./bp3;
    lambdap = bp1./(1-rhod);
end
function lambdaw = lwfn(bigpi,beta,epsw,thetaw,alpw)
    gamw=thetaw*(1+epsw);
    eps1w = epsw*( (1-alpw)./(1-alpw*bigpi.^(gamw-1)) ).^(gamw/(gamw-1));
    eps2w = eps1w.*(1-alpw*beta*bigpi.^(gamw-1)) ./ (1-alpw*beta*bigpi.^(-1));
    eps3w = eps1w.*(1-alpw*beta*bigpi.^(2*gamw))./(1-alpw*beta*bigpi.^gamw);
    kappaw = (1+eps1w).*(1-alpw*bigpi.^(gamw-1)).*(1-alpw*beta*bigpi.^(2*gamw)) ./...
        ( alpw*bigpi.^(gamw-1).*((1+eps3w).*(1-eps2w.*gamw./(gamw-1-eps2w))+gamw) );
    kappadwtilde = (1+eps3w).*(1-alpw*bigpi.^(gamw-1)).*(1-alpw*beta*bigpi.^(gamw-1)) ./...
        ( alpw*bigpi.^(gamw-1).*((1+eps3w).*(1-eps2w*(1+gamw)/(gamw-1))+gamw*(1-eps2w./(gamw-1))) );
    kappadw = gamw*( kappaw.*(1+1./(1+eps1w))-kappadwtilde ) - alpw*beta*bigpi.^(2*gamw) - 1./(alpw*bigpi.^(gamw-1));
    rhodw = alpw*bigpi.^(-1).*(1+eps1w.*bigpi.^gamw)./(1+eps1w);
    kappaedw = -eps1w*alpw.*bigpi.^(-1).*(bigpi.^gamw-1)./( (1+eps1w).*(1-alpw*bigpi.^(-1)) );
    bw3 = 1-kappaedw.*(kappadw+beta*bigpi.*rhodw);
    bw1 = kappaedw.*(1+rhodw.*(kappadw+beta*bigpi.*rhodw))./bw3;
    lambdaw = bw1./(1-rhodw);
end
   