% "A Theory of Intrinsic Inflation Persistence" 
% by Takushi Kurozumi and Willem Van Zandweghe
% Figure 6
clear; clc
h = 32;
%% Calibration
beta = 0.99;
epsp = -3;
epsw = -3;
thetap = 10;
thetaw = 10;
alpp = 0.75;
alpw = 0.75;
% sigman = 1;
phip = 1.5;
phiy = 0.125;
phidy = 0;
rho1 = 0.8;
rho_i = 0; 
std_i = 0.0025; 
rho_a = 0;
std_a = 0;
shocks = [rho_i std_i; rho_a std_a];
%% Compute IRFs
bigpi = 1.067^0.25;
    [~,~,irf1,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
bigpi = 1.02^0.25;
    [~,~,irf2,eu] = ATIIP_fun(bigpi,beta,epsp,epsw,thetap,thetaw,alpp,alpw,phip,phiy,phidy,rho1,shocks,h);
    if sum(eu)<2; disp('No unique solution'); end
%% Plot responses to a one-standard-deviation accommodative shock
xlim = [1 h+1];
xtick = (1:4:h+1);
figure
subplot(2,2,1)
    ha = plot([400*irf1(1,:); 400*irf2(1,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(gca,'YLim',[ -0.001 0.06],'YTick',[0 0.02 0.04 0.06])
    ylabel('pp   ','Rotation',0)
    hleg = legend([ ha(1) ha(2) ],'$\overline{\pi}=6.7\%$',...
        '$\overline{\pi}=2.0\%$','Location','NorthEast');
    set(hleg,'Interpreter','latex')
    title('Inflation')
subplot(2,2,2)
    ha = plot([100*irf1(8,:); 100*irf2(8,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    set(gca,'YLim',[ -0.001 0.06],'YTick',[0 0.02 0.04 0.06])
   	ylabel('%   ','Rotation',0)
    title('RMC of goods production')
subplot(2,2,3)
    ha = plot([100*irf1(5,:); 100*irf2(5,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    xlabel('Quarters since shock')
    ylabel('%   ','Rotation',0)
    set(gca,'YLim',[-0.001 0.03],'YTick',[0 0.01 0.02 0.03 ])
   title('RMC of goods aggregation')
 subplot(2,2,4)
    ha = plot([100*irf1(6,:); 100*irf2(6,:)]');
    set(gca,'FontSize',7)
    set(gca,'XLim',xlim,'XTick',xtick,'XTickLabel',{'0','4','8','12','16','20','24','28','32'})
    set(ha(1),'LineWidth',1.2,'LineStyle','-','Color',[0 0 1]);
    set(ha(2),'LineWidth',1.2,'LineStyle','--','Color',[0 0 0]);
    xlabel('Quarters since shock')
    ylabel('%   ','Rotation',0)
    set(gca,'YLim',[-0.004 0.06],'YTick',[0 0.02 0.04 0.06 ])
   title('RMC of labor aggregation')
  
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [5 3.4]);
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperPosition', [-0.3 -0.1 5.6 3.6 ]);
set(gcf, 'renderer', 'painters');
print(gcf, '-dpdf', 'fig6_effect_trend_infl.pdf');