% "A Theory of Intrinsic Inflation Persistence" 
% Figure 8
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear
clc
delete *.asv
path('figure8files',path);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
X = readtable('figure8data.txt');% Sample 1951Q1-2019Q4
X = table2array(X);
[T,N]=size(X);
Time=X(2:T,1);
LogRealGDP=100*log(X(:,2));
LogRealConsumption=100*log(X(:,3));
LogRealInvestment=100*log(X(:,4));
ShortRate=X(:,5);
LogGDPDeflator=log(X(:,6));
M1=X(:,7);
NominalGDP=X(:,8);
M1Velocity=NominalGDP./M1;
Inflation=400*diff(LogGDPDeflator);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Y=[Inflation LogRealGDP(2:end) ShortRate(2:end) LogRealConsumption(2:end) M1Velocity(2:end) LogRealInvestment(2:end)];
[T,N]=size(Y);
Horizon=20*4;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
NumberOfCointegrationVectors=3;
NumberOfPermanentShocks=N-NumberOfCointegrationVectors;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lag order selection:
MaxLagOrder=4*2;
LagOrderSIC=varplagselect(Y,'Y',MaxLagOrder,'SIC',1);
LagOrderHannanQuinn=varplagselect(Y,'Y',MaxLagOrder,'HQQ',1);
LagOrder=max([LagOrderSIC LagOrderHannanQuinn]'); % The lag order has sto be at least 2 in levels
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The estimated VECM:
[Alpha,CSI0,CSI,A,B,U,Omega,MaxLogLikelihood,TraceStatistic,TestStatistic_h_versus_hplus1]=JohansenCointegratedVAREstimates(Y,LagOrder+1);
% For critical values, see Hamilton (1994, Tables B.10-B.11)
% Here we extract the estimates of the cointegrated VAR conditional on 2 cointegration vectors:
MU=Alpha(:,:,NumberOfCointegrationVectors); % The intercept, B0
BB=reshape(squeeze(CSI(:,:,:,NumberOfCointegrationVectors)),N,N*LagOrder); % The VAR matrices, B1, B2, ..., Bp
GG=CSI0(:,:,NumberOfCointegrationVectors); % The error-correction matrix, G = - B*A'
UU=U(:,:,NumberOfCointegrationVectors)'; % The reduced-form shocks
VAR=Omega(:,:,NumberOfCointegrationVectors); % The VAR's covariance matrix
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computing the long-run impacts of the shocks analytically:
%
[VV,DD]=eig(VAR);
A0Start=VV*DD.^0.5;
% We have the matrix of the loadings:
Alpha=-B(:,1:NumberOfCointegrationVectors);
% and the matrix of the cointegration vectors:
Beta=A(:,1:NumberOfCointegrationVectors);
AlphaOrthComp=orthcomp(Alpha);
BetaOrthComp=orthcomp(Beta);
disp('The property of the orthogonal complement of a given matrix can be seen')
disp('immediately as follows, with reference to Alpha (for Beta it is the same thing):')
AlphaOrthComp'*Alpha
Alpha'*AlphaOrthComp
C=BetaOrthComp*MyInverse(AlphaOrthComp'*(eye(N)-sum(CSI(:,:,:,NumberOfCointegrationVectors),3))*BetaOrthComp)*AlphaOrthComp';
A0=GetA0MoneyVelocity(C,A0Start,N,NumberOfPermanentShocks);
LRI=C*A0;
LRI*1000
%
EE=A0\UU';
%
HOR=(0:1:Horizon)';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
IRFs_SimpleEstimate=GetIRFsCointegratedVECM(A0,BB,GG,LagOrder,N,Horizon,LRI,NumberOfPermanentShocks);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Here we bootstrap the cointegrated VAR to characterize the extent of uncertainty about the estimates:
IRFSS_SIMPLE=IRFs_SimpleEstimate;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
NumberOfBootstraps=1000;
%
IRFs_Bootstrapped=zeros(Horizon+1,size(IRFs_SimpleEstimate,2),size(IRFs_SimpleEstimate,3),NumberOfBootstraps);
%
kk=1;
while kk<=NumberOfBootstraps
    NumberOfBootstraps-kk+1
    [~,YY]=BootstrapCointegratedVARP(Y,MU,GG,reshape(BB,N,N,LagOrder),demean(UU),T,1);
    [alpha,csi0,csi,stored_a,stored_b,u,omega]=JohansenCointegratedVAREstimates(YY,LagOrder+1);
    % Here we extract the estimates:
    mu=alpha(:,:,NumberOfCointegrationVectors);
    bb=reshape(squeeze(csi(:,:,:,NumberOfCointegrationVectors)),N,N*LagOrder);
    gg=csi0(:,:,NumberOfCointegrationVectors);
    % Here we get the coefficients of the representation for the corresponding VAR in levels:
    [mumu,bbbb]=GetVARInLevelsFromVECM(mu,reshape(bb,N,N,LagOrder),gg);
    %
    % Here we check that the estimated number of unit roots is the right one:
    absrootsvarinlevels=sort(abs(varroots(LagOrder+1,N,[mumu reshape(bbbb,N,N*(LagOrder+1))])));
    if sum(abs(absrootsvarinlevels-1)<1.0e-10)==(N-NumberOfCointegrationVectors)
        alpha=-stored_b(:,NumberOfCointegrationVectors);
        beta=stored_a(:,NumberOfCointegrationVectors);
        if (alpha'*(eye(N)-sum(bbbb,3))*beta)~=0
            gg=csi0(:,:,NumberOfCointegrationVectors);
            uu=u(:,:,NumberOfCointegrationVectors)';
            var=omega(:,:,NumberOfCointegrationVectors);
            [vv,dd]=eig(var);
            a0start=vv*dd.^0.5;
            alphaorthcomp=orthcomp(alpha);
            betaorthcomp=orthcomp(beta);
            c=betaorthcomp*MyInverse(alphaorthcomp'*(eye(N)-sum(csi(:,:,:,NumberOfCointegrationVectors),3))*betaorthcomp)*alphaorthcomp';
            a0=GetA0MoneyVelocity(c,a0start,N,NumberOfPermanentShocks);
            lri=c*a0;
            ee=a0\uu';
            irfs=GetIRFsCointegratedVECM(a0,bb,gg,LagOrder,N,Horizon,lri,NumberOfPermanentShocks);
            IRFs_Bootstrapped(:,:,:,kk)=irfs;
            kk=kk+1;
        end
    end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                         I: The IRFs:
SortedIRFs_Bootstrapped=sort(IRFs_Bootstrapped,4);
MedianIRFs_Bootstrapped=SortedIRFs_Bootstrapped(:,:,:,fix(NumberOfBootstraps/2));
%
kk=1;
while kk<=NumberOfBootstraps
    IRFs_Bootstrapped(:,:,:,kk)=IRFs_Bootstrapped(:,:,:,kk)-MedianIRFs_Bootstrapped+IRFs_SimpleEstimate;
    kk=kk+1;
end
Percentiles=fix(NumberOfBootstraps*[0.5 0.16 0.84 0.05 0.95]');
%
Hor=(0:1:Horizon)';
%
SortedIRFs_Bootstrapped=sort(IRFs_Bootstrapped,4);
PercentilesIRFs_Bootstrapped=SortedIRFs_Bootstrapped(:,:,:,Percentiles);
%
save irfdata PercentilesIRFs_Bootstrapped IRFs_SimpleEstimate Hor N
Shock=1; % Inflation shock
Variable=1;

% Define HTMl colors/transparency
lgrey = [.65 .65 .65];
dgrey = [.2 .2 .2];
a = .23; %transparency
l = 'none'; %linestyle of line around shaded area

Hor = Hor';
x2 = [Hor, fliplr(Hor)];

while Variable<=N
    IRFs=squeeze(PercentilesIRFs_Bootstrapped(:,Variable,Shock,:));
    IRF=IRFs_SimpleEstimate(:,Variable,Shock);
    figure(1)
    subplot(3,2,Variable)
    p = plot(Hor,-IRFs(:,1)','b',Hor,zeros(size(Hor)),'k');
    p(1).LineWidth = 1.2;
    p(2).LineWidth = 0.6;
    hold on
    inBetween = [-IRFs(:,2)', fliplr(-IRFs(:,3)')];
    fill(x2,inBetween,dgrey, 'FaceAlpha',a,'LineStyle','none');
    inBetween2 = [-IRFs(:,4)', fliplr(-IRFs(:,5)')];
    fill(x2,inBetween2,lgrey, 'FaceAlpha',a,'LineStyle','none');
    xlim([0 Horizon])
    if Variable==1
        title('Inflation')
       	ylabel('pp   ','Rotation',0)
        set(gca,'YLim',[-0.8 0.4],'YTick',[-0.8 -0.4 0 0.4])
    elseif Variable==2
        title('Real GDP')
       	ylabel('%  ','Rotation',0)
        set(gca,'YLim',[-1.2 0.4],'YTick',[-1.2 -0.8 -0.4 0 0.4])
    elseif Variable==3
        title('Interest Rate')
       	ylabel('pp   ','Rotation',0)
        set(gca,'YLim',[-1 0.5],'YTick',[-1 -0.5 0 0.5])
    elseif Variable==4
        title('Real consumption')
       	ylabel('%  ','Rotation',0)
        set(gca,'YLim',[-0.8 0.4],'YTick',[-0.8 -0.4 0 0.4])
    elseif Variable==5
        title('M1 Velocity')
        xlabel('Quarters since shock')
       	ylabel('%  ','Rotation',0)
    elseif Variable==6
        title('Real investment')
        xlabel('Quarters since shock')
       	ylabel('%  ','Rotation',0)
        set(gca,'YLim',[-3.5 1],'YTick',[-3 -2 -1 0 1])
    else
    end
    Variable=Variable+1;
end

set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [5 5]);
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperPosition', [-0.3 -0.1 5.6 5.2 ]);
set(gcf, 'renderer', 'painters');
print(gcf, '-dpdf', 'fig8_LongRunIRFs.pdf');
