function [XX,YY]=BootstrapCointegratedVARP(Y,Alpha,CSI0,CSI,E,T,NBootstrap)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function [XX,YY]=BootstrapCointegratedVARP(Y,Alpha,CSI0,CSI,E,T,NBootstrap)
% This program bootstraps an estimated cointegrated VAR(p).
%                                             Input of the program is:
%
% Y             = the matrix containing the original I(1) series
% Alpha         = the intercept estimate in the Johansen procedure
% CSI0          = the estimate of the matrix on Y(t-1) in the Johansen procedure
% CSI           = the estimates of the matrices on DY(t-1), ..., DY(t-p+1) in the Johansen procedure
% E             = the residuals, stacked in columns
% T             = length of the simulationS
% NBootstrap    = number of bootstrapped replications
%
%                                             Output of the program is:
%
% XX            = the bootstrapped series in differences
% YY            = the bootstrapped series in levels
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nargin<7
    NBootstrap=1;
end
%
X=diff(Y);
[N,K]=size(E);
Indices=fix(rand(T+2000,NBootstrap)*(N-0.01))+1;
LagOrder=size(CSI,3);
CSI=reshape(CSI,K,K*LagOrder);
%
XX=zeros(T,K,NBootstrap);
YY=zeros(T,K,NBootstrap);
zz=1;
while zz<=NBootstrap
    % zz
    BootstrappedE=E(Indices(:,zz),:);
    xx=zeros(K,T+2000);
    xx(:,1:LagOrder+1)=[zeros(K,1) X(1:LagOrder,:)']; 
    yy=zeros(K,T+2000);
    yy(:,1:LagOrder+1)=Y(1:LagOrder+1,:)'; 
    for tt=LagOrder+1:T+2000
        xx(:,tt)=Alpha+CSI*vec(fliplr(xx(:,tt-LagOrder:tt-1)))+CSI0*yy(:,tt-1)+BootstrappedE(tt,:)';
        yy(:,tt)=yy(:,tt-1)+xx(:,tt);
    end
    xx=xx(:,2000+1:T+2000)';
    yy=yy(:,2000+1:T+2000)';
    XX(:,:,zz)=xx;
    YY(:,:,zz)=yy;
    zz=zz+1;
end






